pro wwz
;-------------------------------------------------------------------------------
;An IDL 5.4 (and later) .pro useful for plotting the output files of WWZ runs.
;Written by M. Templeton, AAVSO.
;
;This .pro may be freely modified to suit your needs.  Please do not
;redistribute without permission of the AAVSO.
;-------------------------------------------------------------------------------

; uncomment the following to generate postscript output
; set_plot,'ps'
; print,'output filename?'
; read,fn
; device,filename=fn,/color,/inches,xsize=7.0,ysize=9.5,xoffset=+0.3,$
;            yoffset=+0.3

; uncomment the following to generate on-screen output
device,retain=2,decomposed=0
window,0,xsize=640,ysize=480


;suggested colors: rainbow=13, rainbow18=38,eosb=27,rainbow+white=39
icolor=39
loadct,icolor
!p.charsize=1.0


instring1='a'
instring2='a'
instring3='a'
print,'Input wwz result path+file name:'
read,instring1
print,'Input your data file path+file name:'
read,instring2
print,'Name of object?'
read,instring3

infile1=instring1
infile2=instring2


openr,1,infile1

a='a'
t0=0.d0 & t1=0.d0 & f0=0.d0 & f1=0.d0 & dt=0.d0 & df=0.d0

;read the header
readf,1,a
readf,1,t0,t1,dt,format='(13x,f12.4,8x,f12.4,8x,f8.4)'
readf,1,f0,f1,df,format='(12x,f10.7,8x,f10.7,7x,f9.7)'
readf,1,a

;determine array sizes based on number of taus and frequencies
nt=1+round((t1-t0)/dt)
nf=1+round((f1-f0)/df)
i=0
j=0
k=0
time=dblarr(nt)
freq=dblarr(nf)
z=dblarr(nt,nf)

;now read in the array...
while (i lt nt) do begin
 j=0
 while (j lt nf) do begin
  readf,1,t,f,w,a
  time(i)=t
  freq(j)=f
; assign "a" to z for amplitudes, "w" for Z-statistic
  z(i,j)=a
  j=j+1
 endwhile
 i=i+1
endwhile

;all done, so close the input file
close,1
;convert the time to kilodays since 2440000
time=(time-2400000.d0)/1000.d0

;make a surface plot.  ax=90,az=0 gives an overhead perspective
!p.position=[0.12,0.35,0.95,0.95]
!x.style=5
!y.style=1
!z.style=4
!x.title=''
!y.title='frequency (cyc/d)'
!x.range=[min(time),max(time)]
!y.range=[min(freq),max(freq)]
shade_surf,z,time,freq,ax=90,az=0,shades=bytscl(z)
xyouts,0.75*max(time)+0.25*min(time),0.9*max(freq)+0.1*min(freq),instring3




;now make the lightcurve plot right underneath it

!p.position=[0.12,0.10,0.95,0.35]

openr,1,infile2

i=long(0)
t=0.d0 & m=0.d0
time=dblarr(1000000) & mag=dblarr(1000000)
while not eof(1) do begin
 readf,1,t,m
 time(i)=t
 mag(i)=m
 i=i+1
endwhile
close,1
time=(time[0:i-1]-2400000.d0)/1000.d0
mag=mag[0:i-1]
!x.style=1
!y.style=1
!y.range=[max(mag),min(mag)]
!y.title='visual magnitude'
!x.title='JD - 2400000 (1000s of days)'
plot,time,mag,psym=3,/noerase

;reset the !p.position variable
!p.position=[0.12,0.05,0.95,0.95]

;uncomment the following to generate postscript output
;device,/close


end
